package supplier

import (
	"context"
	"git.oa00.com/supply-chain/service/client"
	"git.oa00.com/supply-chain/service/lib/bean"
	"github.com/shopspring/decimal"
)

type afsAudit struct {
}
type ArgsAfsAuditLists struct {
	Search AfsAuditSearch
	Page   bean.Page
}
type AfsAuditSearch struct {
	Status           uint // 0=全部 1=待审核 2=审核通过 3=审核驳回
	AfsSn            string
	OrderSubSn       string
	CreatedStartDate string
	CreatedEndDate   string
}

type ReplyAfsAuditLists struct {
	Lists []AfsAuditItem
	Total int64
}
type AfsAuditItem struct {
	Id            uint            `json:"id"`
	AfsSn         uint64          `json:"afsSn"`
	OrderSubSn    uint64          `json:"orderSubSn"`
	Status        uint            `json:"status"`
	Quantity      uint            `json:"quantity"`
	OrderSubAfsId uint            `json:"orderSubAfsId"`
	RefundFee     decimal.Decimal `json:"refundFee"`
	Remark        string          `json:"remark"`
	Result        string          `json:"result"`
	Notes         string          `json:"notes"`
	RefundId      uint            `json:"refundId"`
	ApplyUserId   uint            `json:"applyUserId"`
	AuditUserId   uint            `json:"auditUserId"`
	AuditAt       int64           `json:"auditAt"`
}

// Lists @Title 售后审核列表
func (a *afsAudit) Lists(ctx context.Context, args ArgsAfsLists) (reply ReplyAfsLists, err error) {
	xClient, err := client.GetClient(a)
	if err != nil {
		return
	}
	err = xClient.Call(ctx, "Lists", args, &reply)
	return
}

type ArgsAfsAuditAdopt struct {
	AuditUserId uint
	AfsAuditId  uint
}

// Adopt @Title 审核通过
func (a *afsAudit) Adopt(ctx context.Context, args ArgsAfsAuditAdopt) error {
	xClient, err := client.GetClient(a)
	if err != nil {
		return err
	}
	reply := 0
	return xClient.Call(ctx, "Adopt", args, &reply)
}

type ArgsAfsAuditReject struct {
	AuditUserId uint
	Remark      string
	AfsAuditId  uint
}

// Reject @Title 审核驳回
func (a *afsAudit) Reject(ctx context.Context, args ArgsAfsAuditReject) error {
	xClient, err := client.GetClient(a)
	if err != nil {
		return err
	}
	reply := 0
	return xClient.Call(ctx, "Reject", args, &reply)
}

type ArgsSetAfsAuditPrice struct {
	Price  decimal.Decimal
	Switch uint
}

// SetAfsAuditPrice @Title 设置需要审核金额
func (a *afsAudit) SetAfsAuditPrice(ctx context.Context, args ArgsSetAfsAuditPrice) error {
	xClient, err := client.GetClient(a)
	if err != nil {
		return err
	}
	reply := 0
	return xClient.Call(ctx, "SetAfsAuditPrice", args, &reply)
}
